@@ -202,19 +202,19 @@ class EtiquetteBase:
                     return
         return
 
-    def drawBarcode(self, width = 72, height = 6, x = 'center', y = 10):
+    def drawBarcode(self, width = 72, height = 6, x = 10, y = 10):
         """
         Inscrit un code barre dans un pylabel ;
         @param width largeur du code-barre, en mm (47 mm par défaut)
         @param height hauteur du code-barre, en mm (6 mm par défaut)
-        @param x abscisse du début ("center" par défaut)
+        @param x abscisse du début (10 mm par défaut)
         @param y ordonnée du début (10 mm par défaut)
         """
         bc = createBarcodeDrawing(
             'Code128', value="{code:9d}".format(**self.__dict__),
             width = mm2pt(width), height = mm2pt(height))
-        dx = -12 # ce décalage a été réglé expérientalement, au pif
-        bc.translate(dx, mm2pt(10))
+        dx = -mm2pt(14) # décalage de x trouvé au pif
+        bc.translate(mm2pt(x) + dx, mm2pt(y))
         self.pylabel.add(bc)
         return
 
@@ -472,6 +472,7 @@ class CartesMembre(EtiquetteBase):
     def __init__(self, eleve):
         EtiquetteBase.__init__(self)
         self.eleve = eleve
+        self.code = eleve.no_caution
         self.pylabel = None # instance de pylabel
         self.w = None       # sa largeur, en points
         self.h = None       # sa hauteur, en points
@@ -505,11 +506,11 @@ class CartesMembre(EtiquetteBase):
         self.pylabel.add(s)
         return
 
-    def drawMembre(self, x="center", y=60):
+    def drawMembre(self, x="center", y=58):
         """
         Inscrit les données du membre
         @param x l'abscisse de la chaîne à tracer ("center" par défaut)
-        @param y l'ordonnée de la chaîne à tracer (60 mm par défaut)
+        @param y l'ordonnée de la chaîne à tracer (58 mm par défaut)
         """
         no = ".........."
         if self.eleve.no_caution >= MIN_NO_CAUTION:
@@ -608,6 +609,7 @@ class CartesMembre(EtiquetteBase):
         self.pylabel, self.w, self.h = label, w, h
         self.drawEts()
         self.drawTitle()
+        self.drawBarcode(width=30, height=4, x=83, y=102)
         self.drawMembre()
         self.drawNomPrenom()
         self.drawDate()
@@ -942,7 +944,7 @@ ADRESSE : .....................................................................
             fontSize=12)
         self.adjustXY(s, x + 36, y)
         self.pylabel.add(s)
-        s = self.string("Masse : 10 €", fontSize=12)
+        s = self.string("Masse : 12 €", fontSize=12)
         self.adjustXY(s, x, y-6)
         self.pylabel.add(s)
         s = self.string("Esp. ☐  Chq. ☐", fontSize=12)
