@@ -275,4 +275,7 @@ urlpatterns = [
     path('efface_caution_go', ajaxviews.efface_caution_go, name='efface_caution_go'),
     path('recompte_livres', ajaxviews.recompte_livres, name='recompte_livres'),
     path('del_message', ajaxviews.del_message, name='del_message'),
+    path('messages_eleves', views_download.messages_eleves, name='messages_eleves'),
+    path('recompte_pour_maintenant', ajaxviews.recompte_pour_maintenant, name='recompte_pour_maintenant'),
+    re_path(r"^pour_qui_ce_livre/(?P<ident>.*)", views_download.pqcl),
 ]
