@@ -322,11 +322,7 @@ def catalogue(request):
         m.split_categories = m.categories.split(", ")
         # split_options insère des <br> dans un nom d'option et
         # modifie MATHEMATIQUES (mot trop long)
-        m.split_option = m.lib_option.replace(".&", ". &").\
-            replace(" & ", " & ").replace(" ","<br>").\
-            replace("-","<br>-").replace("S.P", "S·P").\
-            replace(".", ".<br>").replace("MATHEMATIQUES", "MATHS").\
-            replace("<br><br>", "<br>")
+        m.split_option = m.lib_option.replace(", ",",<br>")
     return render_common(
         request, 'gestion/catalogue.html',
         _("Catalogue de la Coopérative"),
@@ -542,7 +538,8 @@ def cartes(request):
     Qexpr= Q(libelle__startswith=filtrage[0])
     for f in filtrage[1:]:
         Qexpr= Qexpr | Q(libelle__startswith=f)
-    classes = Classes.objects.filter(compte__gt=0).filter(Qexpr)
+    classes = Classes.objects.filter(
+        compte__gt=0).filter(Qexpr).order_by('libelle')
     result= render_common(
         request,'gestion/cartes.html',
         _("Gestion des cartes de membre"),
